@@ -21,7 +21,7 @@ class Manot:
             data_provider: Literal['s3', 'local']
     ) -> Union[bool, dict]:
 
-        url = f"{self.__url}/api/v1/collector/setup"
+        url = f"{self.__url}/api/v1/setup/"
         data = {
             "name": name,
             "images_path": images_path,
@@ -71,7 +71,7 @@ class Manot:
             weight_name: Optional[str] = None,
     ) -> Union[bool, dict]:
 
-        url = f"{self.__url}/api/v1/real_time/"
+        url = f"{self.__url}/api/v1/insight/"
         data = {
             "name": name,
             "setup_id": setup_id,
@@ -96,7 +96,7 @@ class Manot:
 
     def get_insight(self, insight_id: int) -> Union[bool, None, dict]:
 
-        url = f"{self.__url}/api/v1/real_time/{insight_id}"
+        url = f"{self.__url}/api/v1/insight/{insight_id}"
 
         try:
             response = requests.get(url=url).json()
